@@ -11,9 +11,12 @@
 #    under the License.
 
 import os
+import time
+import uuid
 
 import fixtures
 import os_client_config
+import six
 import tempest_lib.cli.base
 import testtools
 
@@ -152,7 +155,7 @@ class ClientTestBase(testtools.TestCase):
         self.image = pick_image(self.client.images.list())
 
         # create a CLI client in case we'd like to do CLI
-        # testing. tempest_lib does this realy weird thing where it
+        # testing. tempest_lib does this really weird thing where it
         # builds a giant factory of all the CLIs that it knows
         # about. Eventually that should really be unwound into
         # something more sensible.
@@ -170,3 +173,30 @@ class ClientTestBase(testtools.TestCase):
     def nova(self, *args, **kwargs):
         return self.cli_clients.nova(*args,
                                      **kwargs)
+
+    def wait_for_volume_status(self, volume, status, timeout=60,
+                               poll_interval=1):
+        """Wait until volume reaches given status.
+
+        :param volume_id: uuid4 id of given volume
+        :param status: expected status of volume
+        :param timeout: timeout in seconds
+        :param poll_interval: poll interval in seconds
+        """
+        start_time = time.time()
+        while time.time() - start_time < timeout:
+            volume = self.client.volumes.get(volume.id)
+            if volume.status == status:
+                break
+            time.sleep(poll_interval)
+        else:
+            self.fail("Volume %s did not reach status %s after %d s"
+                      % (volume.id, status, timeout))
+
+    def name_generate(self, prefix='Entity'):
+        """Generate randomized name for some entity.
+
+        :param prefix: string prefix
+        """
+        name = "%s-%s" % (prefix, six.text_type(uuid.uuid4()))
+        return name
