@@ -20,6 +20,7 @@ from six.moves import urllib
 
 from novaclient import base
 from novaclient import client
+from novaclient import exceptions as exc
 
 
 class Version(base.Resource):
@@ -40,7 +41,20 @@ class VersionManager(base.ManagerWithFind):
         """Returns info about current version."""
         if self._is_session_client():
             url = self.api.client.get_endpoint().rsplit("/", 1)[0]
-            return self._get(url, "version")
+            # NOTE(sdague): many service providers don't really
+            # implement GET / in the expected way, if we do a GET /v2
+            # that's actually a 300 redirect to /v2/... because of how
+            # paste works. So adding the end slash is really important.
+            url = "%s/" % url
+            try:
+                return self._get(url, "version")
+            except exc.Unauthorized:
+                # NOTE(sdague): RAX's repose configuration blocks
+                # access to the versioned endpoint, which is
+                # definitely non-compliant behavior. However, there is
+                # no defcore test for this yet. Remove this code block
+                # once we land things in defcore.
+                return None
         else:
             # NOTE(andreykurilin): HTTPClient doesn't have ability to send get
             # request without token in the url, so `self._get` doesn't work.
